Makefiles...
authorJan Vrany <jan.vrany@fit.cvut.cz>
Sat, 20 Jun 2009 20:38:34 +0000
changeset 123 679becd265ea
parent 122 44903fb09c08
child 124 837b40246283
Makefiles...
xmlreaderimpl/trunk/Make.proto
xmlreaderimpl/trunk/Make.spec
xmlreaderimpl/trunk/XMLv2__ExpatXMLReader.st
xmlreaderimpl/trunk/XMLv2__ExpatXMLReaderTests.st
xmlreaderimpl/trunk/abbrev.stc
xmlreaderimpl/trunk/bc.def
xmlreaderimpl/trunk/bmake.bat
xmlreaderimpl/trunk/extensions.st
xmlreaderimpl/trunk/libInit.cc
xmlreaderimpl/trunk/makefile
xmlreaderimpl/trunk/nt.mak
xmlreaderimpl/trunk/stx_goodies_xmlsuite_xmlreaderimpl.st
--- a/xmlreaderimpl/trunk/Make.spec	Sat Jun 20 20:32:35 2009 +0000
+++ b/xmlreaderimpl/trunk/Make.spec	Sat Jun 20 20:38:34 2009 +0000
@@ -1,31 +1,23 @@
 # $Header$
 #
-# --- Make.spec created by stmkmp at Sun Oct 26 20:52:03 CET 2008
+# DO NOT EDIT 
+# automagically generated from the projectDefinition: stx_goodies_xmlsuite_xmlreaderimpl.
+#
+# Warning: once you modify this file, do not rerun
+# stmkmp or projectDefinition-build again - otherwise, your changes are lost.
 #
 # This file contains specifications which are common to all platforms.
 #
-# Warning: once you modify this file, do not rerun
-# stmkmp again - otherwise, your changes are lost.
-#
-# This file contains definitions for Unix based platforms.
-#
 
-
-
-
-# module and directory-in-module;
-# these should correspond to the directory hierarchy
-# location (otherwise, ST/X will have a hard time to
-# find out the packages location from its packageID)
+# Do NOT CHANGE THESE DEFINITIONS
+# (otherwise, ST/X will have a hard time to find out the packages location from its packageID,
+#  to find the source code of a class and to find the library for a package)
 MODULE=stx
 MODULE_DIR=goodies/xmlsuite/xmlreaderimpl
 PACKAGE=$(MODULE):$(MODULE_DIR)
 
-# the name of your classLibrary:
-LIBNAME=libstx_goodies_xmlsuite_xmlreaderimpl
 
-
-# Argument(s) to the stc compiler.
+# Argument(s) to the stc compiler (stc --usage).
 #  -H.         : create header files locally
 #                (if removed, they will be created as common
 #  -Pxxx       : defines the package
@@ -45,7 +37,7 @@
 STCLOCALOPTIMIZATIONS=+optspace3
 
 
-# Argument(s) to the stc compiler.
+# Argument(s) to the stc compiler (stc --usage).
 #  -warn            : no warnings
 #  -warnNonStandard : no warnings about ST/X extensions
 #  -warnEOLComments : no warnings about EOL comment extension
@@ -55,12 +47,11 @@
 # STCWARNINGS=-warn
 # STCWARNINGS=-warnNonStandard
 # STCWARNINGS=-warnEOLComments
-STCWARNINGS=
+STCWARNINGS=-warnNonStandard
 
-OBJS= \
-    stx_goodies_xmlsuite_xmlreaderimpl.$(O) \
-    XMLv2__ExpatXMLReader.$(O) \
-    XMLv2__XercesCXMLReader.$(O) \
-    XMLv2__VWSAXBuilder.$(O) \
-    XMLv2__VWXMLReader.$(O) 
+COMMON_OBJS= \
+    $(OUTDIR)XMLv2__VWSAXBuilder.$(O) \
+    $(OUTDIR)XMLv2__VWXMLReader.$(O) \
+    $(OUTDIR)stx_goodies_xmlsuite_xmlreaderimpl.$(O) \
 
+
--- a/xmlreaderimpl/trunk/XMLv2__ExpatXMLReader.st	Sat Jun 20 20:32:35 2009 +0000
+++ b/xmlreaderimpl/trunk/XMLv2__ExpatXMLReader.st	Sat Jun 20 20:38:34 2009 +0000
@@ -314,19 +314,6 @@
 
 !ExpatXMLReader methodsFor:'expat events'!
 
-expatUnknownEncoding: aString
-
-    | encoder |
-    encoder := CharacterEncoder encoderFor: aString.
-    (encoder isKindOf: CharacterEncoderImplementations::SingleByteEncoder)
-        ifFalse:[^nil "multibyte encoders not supported"].
-    ^( ( 0 to: 255 ) collect: [:c|encoder decode:c] ) asArray
-
-    "Modified: / 27-10-2008 / 19:09:57 / Jan Vrany <vranyj1@fel.cvut.cz>"
-
-!
-
-
 expatCharacters:aString
 
     | handler |
@@ -470,6 +457,18 @@
     self getContentHandler startPrefix:prefix mappingTo:uri
 
     "Created: / 17-04-2005 / 08:47:52 / janfrog"
+!
+
+expatUnknownEncoding: aString
+
+    | encoder |
+    encoder := CharacterEncoder encoderFor: aString.
+    (encoder isKindOf: CharacterEncoderImplementations::SingleByteEncoder)
+        ifFalse:[^nil "multibyte encoders not supported"].
+    ^( ( 0 to: 255 ) collect: [:c|encoder decode:c] ) asArray
+
+    "Modified: / 27-10-2008 / 19:09:57 / Jan Vrany <vranyj1@fel.cvut.cz>"
+
 ! !
 
 !ExpatXMLReader methodsFor:'expat primitives'!
--- a/xmlreaderimpl/trunk/XMLv2__ExpatXMLReaderTests.st	Sat Jun 20 20:32:35 2009 +0000
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,26 +0,0 @@
-"{ Package: 'stx:goodies/xmlsuite/xmlreaderimpl' }"
-
-"{ NameSpace: XMLv2 }"
-
-XMLReaderTests subclass:#ExpatXMLReaderTests
-	instanceVariableNames:''
-	classVariableNames:''
-	poolDictionaries:''
-	category:'XML Suite-SAX2-XMLReaders-Tests'
-!
-
-
-!ExpatXMLReaderTests methodsFor:'accessing'!
-
-parserClass
-
-    ^ExpatXMLReader
-
-    "Created: / 06-04-2009 / 11:09:54 / Jan Kurs <kursj1@fel.cvut.cz>"
-! !
-
-!ExpatXMLReaderTests class methodsFor:'documentation'!
-
-version
-    ^'$Id$'
-! !
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/xmlreaderimpl/trunk/abbrev.stc	Sat Jun 20 20:38:34 2009 +0000
@@ -0,0 +1,5 @@
+XMLv2::ExpatXMLReader XMLv2__ExpatXMLReader stx:goodies/xmlsuite/xmlreaderimpl 'XML Suite-SAX2-XMLReaders' 0
+XMLv2::XercesCXMLReader XMLv2__XercesCXMLReader stx:goodies/xmlsuite/xmlreaderimpl 'XML Suite-SAX2-XMLReaders' 0
+XMLv2::VWSAXBuilder XMLv2__VWSAXBuilder stx:goodies/xmlsuite/xmlreaderimpl 'XML Suite-SAX2-XMLReaders' 0
+XMLv2::VWXMLReader XMLv2__VWXMLReader stx:goodies/xmlsuite/xmlreaderimpl 'XML Suite-SAX2-XMLReaders' 0
+stx_goodies_xmlsuite_xmlreaderimpl stx_goodies_xmlsuite_xmlreaderimpl stx:goodies/xmlsuite/xmlreaderimpl '* Projects & Packages *' 2
--- a/xmlreaderimpl/trunk/bc.def	Sat Jun 20 20:32:35 2009 +0000
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,6 +0,0 @@
-LIBRARY xmlreaderimpl
-CODE PRELOAD MOVEABLE DISCARDABLE
-SEGMENTS
-   INITCODE    PRELOAD DISCARDABLE
-EXPORTS 
-    _xmlreaderimpl_Init   @1
--- a/xmlreaderimpl/trunk/bmake.bat	Sat Jun 20 20:32:35 2009 +0000
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,1 +0,0 @@
-make.exe -N -f nt.mak %1 %2
--- a/xmlreaderimpl/trunk/extensions.st	Sat Jun 20 20:32:35 2009 +0000
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,4 +0,0 @@
-"{ Package: 'stx:goodies/xmlsuite/xmlreaderimpl' }"
-
-!
-
--- a/xmlreaderimpl/trunk/libInit.cc	Sat Jun 20 20:32:35 2009 +0000
+++ b/xmlreaderimpl/trunk/libInit.cc	Sat Jun 20 20:38:34 2009 +0000
@@ -1,7 +1,7 @@
 /*
  * $Header$
  *
- * DO NOT EDIT
+ * DO NOT EDIT 
  * automagically generated from the projectDefinition: stx_goodies_xmlsuite_xmlreaderimpl.
  */
 #define __INDIRECTVMINITCALLS__
@@ -9,7 +9,7 @@
 
 #ifdef WIN32
 # pragma codeseg INITCODE "INITCODE"
-#endif
+#endif 
 
 #if defined(INIT_TEXT_SECTION) || defined(DLL_EXPORT)
 DLL_EXPORT void _libstx_goodies_xmlsuite_xmlreaderimpl_Init() INIT_TEXT_SECTION;
--- a/xmlreaderimpl/trunk/makefile	Sat Jun 20 20:32:35 2009 +0000
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,18 +0,0 @@
-#
-# DO NOT EDIT 
-# automagically generated from Make.proto (by make mf)
-#
-include ../../../rules/stdHeader
-include ../../../configurations/COMMON/defines
-include ../../../configurations/vendorConf
-include ../../../configurations/myConf
-include ../../../rules/stdHeader2
-include Make.spec
-include Make.proto
-
-BASE_CONF=linux-elf/opt-cs-oc
-BASE_CONF_VENDOR=linux-elf
-CONF_PACKS=
-CONF_TOOLS=
-
-include ../../../rules/stdRules
--- a/xmlreaderimpl/trunk/nt.mak	Sat Jun 20 20:32:35 2009 +0000
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,35 +0,0 @@
-# $Header$
-#
-# --- nt.mak created by stmkmp at Sun Oct 26 20:52:03 CET 2008
-#
-# This file contains make rules for the win32 platform (using borland-bcc).
-#
-# Warning: once you modify this file, do not rerun
-# stmkmp again - otherwise, your changes are lost.
-#
-TOP=..\..\..\
-
-!INCLUDE $(TOP)\rules\stdHeader_nt
-
-!INCLUDE Make.spec
-
-PACKAGE=$(MODULE):$(MODULE_DIR)
-STCLOCALOPT=-I. $(LOCALINCLUDES) -H. $(STCLOCALOPTIMIZATIONS) $(STCWARNINGS) $(LOCALDEFINES) '-P$(PACKAGE)' '-Z$(LIBNAME)' $(COMMONSYMFLAG) $(INITCODESEPFLAG)
-
-ALL::  $(LIBJPEG) $(LIBDIR)\$(LIBNAME).lib $(BINDIR)\$(LIBNAME).dll
-
-
-SYS_INCL=$(SYS_INCL) "-IC:\Program Files\Expat 2.0.1\Source\lib"
-WIN32_IOBJS=$(WIN32_IOBJS) "C:\Program Files\Expat 2.0.1\Source\bcb5\release\libexpats_mtd.lib"
-
-
-
-
-
-
-
-
-!INCLUDE $(TOP)\rules\stdRules_nt
-
-# BEGINMAKEDEPEND --- do not remove this line; make depend needs it
-# ENDMAKEDEPEND --- do not remove this line
--- a/xmlreaderimpl/trunk/stx_goodies_xmlsuite_xmlreaderimpl.st	Sat Jun 20 20:32:35 2009 +0000
+++ b/xmlreaderimpl/trunk/stx_goodies_xmlsuite_xmlreaderimpl.st	Sat Jun 20 20:38:34 2009 +0000
@@ -105,7 +105,7 @@
     "Return a SVN revision number of myself.
      This number is updated after a commit"
 
-    ^ "$SVN-Revision:"nil"$"
+    ^ "$SVN-Revision:"123"$"
 ! !
 
 !stx_goodies_xmlsuite_xmlreaderimpl class methodsFor:'documentation'!
--- a/xmlreaderimpl/trunk/Make.proto	Sat Jun 20 20:32:35 2009 +0000
+++ b/xmlreaderimpl/trunk/Make.proto	Sat Jun 20 20:38:34 2009 +0000
@@ -1,15 +1,18 @@
 # $Header$
 #
-# --- Make.proto created by stmkmp at Sun Oct 26 20:52:03 CET 2008
+# DO NOT EDIT 
+# automagically generated from the projectDefinition: stx_goodies_xmlsuite_xmlreaderimpl.
 #
 # Warning: once you modify this file, do not rerun
 # stmkmp again - otherwise, your changes are lost.
 #
 # The Makefile as generated by this Make.proto supports the following targets:
 #    make         - compile all st-files to a classLib
-#    make install - install the classLib in /opt/smalltalk/...
 #    make clean   - clean all temp files
 #    make clobber - clean all
+#
+# This file contains definitions for Unix based platforms.
+# It shares common definitions with the win32-make in Make.spec.
 
 #
 # position (of this package) in directory hierarchy:
@@ -25,12 +28,13 @@
 # (only define if different from SUBDIRS)
 # ALLSUBDIRS=
 
+REQUIRED_SUPPORT_DIRS=
 
 # if your embedded C code requires any system includes, 
 # add the path(es) here:, 
 # ********** OPTIONAL: MODIFY the next lines ***
 # LOCALINCLUDES=-Ifoo -Ibar
-LOCALINCLUDES=-I$(TOP)/libbasic -I$(TOP)/goodies/xml/vw -I$(TOP)/goodies/xmlsuite/core
+LOCALINCLUDES= -I$(INCLUDE_TOP)/stx/goodies/xmlsuite/core -I$(INCLUDE_TOP)/stx/goodies/xml/vw -I$(INCLUDE_TOP)/stx/libbasic
 
 
 # if you need any additional defines for embedded C code, 
@@ -39,38 +43,29 @@
 # LOCALDEFINES=-Dfoo -Dbar -DDEBUG
 LOCALDEFINES=
 
-
-#
-# The next 2 defines should be left as-is
-#  for a class-library package, you can uncomment the following:
-#  (it does not hurt much, if you leave it as is - but you may NOT
-#   uncomment it if object files are to be loaded individually later).
-# INITCODESEPFLAG=$(SEPINITCODE)
-#
-#  the following MAY ONLY be uncommented for classes/classLibs,
-#  which are ALWAYS statically included in the executable.
-#  (i.e. NEVER for those which are subject to dynamic loading).
-# COMMONSYMFLAG=$(COMMONSYMBOLS)
-#
-PACKAGE=stx:goodies/xmlsuite/xmlreaderimpl
-STCLOCALOPT=-I. $(LOCALINCLUDES) $(STCLOCALOPTIMIZATIONS) $(STCWARNINGS) $(LOCALDEFINES) -H. '-P$(PACKAGE)' '-Z$(LIBNAME)' $(COMMONSYMFLAG) $(INITCODESEPFLAG)
+LIBNAME=libstx_goodies_xmlsuite_xmlreaderimpl
+STCLOCALOPT='-package=$(PACKAGE)' -I. $(LOCALINCLUDES) $(STCLOCALOPTIMIZATIONS) $(STCWARNINGS) $(LOCALDEFINES) -H.  -varPrefix=$(LIBNAME)
 
 
 # ********** OPTIONAL: MODIFY the next line ***
 # additional C-libraries that should be pre-linked with the class-objects
-LD_OBJ_LIBS=support/*.o
+LD_OBJ_LIBS=
+LOCAL_SHARED_LIBS=
 
 
 # ********** OPTIONAL: MODIFY the next line ***
 # additional C targets or libraries should be added below
 LOCAL_EXTRA_TARGETS=
-LOCAL_SHARED_LIBS=-lexpat -lxerces-c
-LDFLAGS+=-static
+
+OBJS= $(COMMON_OBJS) $(UNIX_OBJS)
 
 
 
 all:: preMake classLibRule postMake
 
+pre_objs:: 
+
+
 
 # add more install actions here
 install::
@@ -79,66 +74,56 @@
 installAux::
 
 # add more preMake actions here
-preMake:: support
+preMake::
 
 # add more postMake actions here
 postMake:: cleanjunk
 
+prereq: $(REQUIRED_SUPPORT_DIRS)
+	cd ../../../libbasic && $(MAKE)
+	cd ../../refactoryBrowser/helpers && $(MAKE)
+	cd ../../refactoryBrowser/parser && $(MAKE)
+	cd ../../../libbasic2 && $(MAKE)
+	cd ../../../libcomp && $(MAKE)
+	cd ../../../libboss && $(MAKE)
+	cd ../../../libview && $(MAKE)
+	cd ../../../libbasic3 && $(MAKE)
+	cd ../../../libview2 && $(MAKE)
+	cd ../../refactoryBrowser/changes && $(MAKE)
+	cd ../../xml/vw && $(MAKE)
+	cd ../../../libui && $(MAKE)
+	cd ../../../libwidg && $(MAKE)
+	cd ../../../libwidg3 && $(MAKE)
+	cd ../../../libhtml && $(MAKE)
+	cd ../../refactoryBrowser/browser && $(MAKE)
+	cd ../../../libwidg2 && $(MAKE)
+	cd ../../../libcompat && $(MAKE)
+	cd ../../../libtool && $(MAKE)
+	cd ../../sunit && $(MAKE)
+	cd ../../communication && $(MAKE)
+	cd ../../../libtool2 && $(MAKE)
+	cd ../../refactoryBrowser/lint && $(MAKE)
+	cd $(TOP)/../cvut/fel/libutilui && $(MAKE)
+	cd ../../libtool3 && $(MAKE)
+	cd ../core && $(MAKE)
+	cd . && $(MAKE)
+	cd ../../../librun && $(MAKE)
+
+
+
 cleanjunk::
 
 clean::
 	-rm -f *.o *.H
-	$(MAKE) -C support clean
-	-rm XMLv2__*.so
 
-clobber::
+clobber:: clean
 	-rm -f *.so *.dll
 
 
-support:
-	$(MAKE) -C support OPT=$(OPT)
-
-
-expat: XMLv2__ExpatXMLReader.$(SO)
-
-xerces: XMLv2__XercesCXMLReader.$(SO)
-
-xerces-clean:
-	rm -rf XMLv2__XercesCXMLReader.$(SO) XMLv2__XercesCXMLReader.$(O) 
-
-XMLv2__XercesCXMLReader.$(SO): XMLv2__XercesCXMLReader.$(O) support
-	ld -nostdlib -shared -L/usr/lib -Llib -L/usr/local/lib -L/usr/X11/lib -R.,-Rlib,-R/opt/stx/`cat ../../../RELEASE`/lib/lib,-R/usr/local/lib/stx`cat ../../../RELEASE` -o XMLv2__XercesCXMLReader.$(SO) XMLv2__XercesCXMLReader.$(O) support/*.o -lxerces-c
-
-
-
-XMLv2__ExpatXMLReader.$(SO): XMLv2__ExpatXMLReader.$(O)
-	ld -nostdlib -shared -static -L/usr/lib -Llib -L/usr/local/lib -L/usr/X11/lib -R.,-Rlib,-R/opt/stx/`cat ../../../RELEASE`/lib/lib,-R/usr/local/lib/stx`cat ../../../RELEASE` -o XMLv2__ExpatXMLReader.so XMLv2__ExpatXMLReader.o -lexpat
-
-
-
+# BEGINMAKEDEPEND --- do not remove this line; make depend needs it
+$(OUTDIR)XMLv2__VWSAXBuilder.$(O) XMLv2__VWSAXBuilder.$(H): XMLv2__VWSAXBuilder.st $(INCLUDE_TOP)/stx/goodies/xml/vw/SAXBuilder.$(H) $(INCLUDE_TOP)/stx/goodies/xml/vw/NodeBuilder.$(H) $(INCLUDE_TOP)/stx/goodies/xml/vw/XMLNodeBuilder.$(H) $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(STCHDR)
+$(OUTDIR)XMLv2__VWXMLReader.$(O) XMLv2__VWXMLReader.$(H): XMLv2__VWXMLReader.st $(INCLUDE_TOP)/stx/goodies/xmlsuite/core/XMLv2__XMLReader.$(H) $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(INCLUDE_TOP)/stx/goodies/xml/vw/XMLParserStX.$(H) $(INCLUDE_TOP)/stx/goodies/xml/vw/XMLParser.$(H) $(INCLUDE_TOP)/stx/goodies/xml/vw/StreamWrapper.$(H) $(INCLUDE_TOP)/stx/libbasic/Link.$(H) $(STCHDR)
+$(OUTDIR)stx_goodies_xmlsuite_xmlreaderimpl.$(O) stx_goodies_xmlsuite_xmlreaderimpl.$(H): stx_goodies_xmlsuite_xmlreaderimpl.st $(INCLUDE_TOP)/stx/libbasic/LibraryDefinition.$(H) $(INCLUDE_TOP)/stx/libbasic/ProjectDefinition.$(H) $(INCLUDE_TOP)/stx/libbasic/Object.$(H) $(STCHDR)
 
-$(INSTALLBASE)::
-	@test -d $@ || mkdir $@
-
-$(INSTALLBASE)/packages:: $(INSTALLBASE)
-	@test -d $@ || mkdir $@
-
-$(INSTALLBASE)/packages/$(MODULE):: $(INSTALLBASE)/packages
-	@test -d $@ || mkdir $@
-
-
-$(INSTALLBASE)/packages/$(MODULE)/$(MODULE_DIR):: $(INSTALLBASE)/packages/$(MODULE)
-	@test -d $@ || mkdir $@
+# ENDMAKEDEPEND --- do not remove this line
 
-# if other things are to be compiled,
-# add target definitions here,
-# and list them in LOCAL_EXTRA_TARGETS above.
-# (care for make syntax - TABS are required in the actions)
-# foo:  foo.o
-#         $(CC) -o foo foo.o
-
-# 'make depend' will add dependency info between
-# BEGIN...END below
-#
-# BEGINMAKEDEPEND --- do not remove this line; make depend needs it
-# ENDMAKEDEPEND --- do not remove this line
@@ -1,15 +1,18 @@
 #
 # Warning: once you modify this file, do not rerun
-# stmkmp again - otherwise, your changes are lost.
+# stmkmp or projectDefinition-build again - otherwise, your changes are lost.
 #
 # The Makefile as generated by this Make.proto supports the following targets: